#!/bin/ash
# This script gathers the RLM configuration info to a tuple file
# and put it in $tuples for filer's use.
set -x

fw_printenv="/usr/local/bin/fw_printenv"

ftpdir="/tmp/config"
final_tuples="$ftpdir/rlm_config_to_filer"
tuples="/mnt/logs/etc/rlm_config_to_filer"
stats="$ftpdir/rlm_stats"

interfaces="/etc/network/interfaces"

log="/var/log/messages"
date=`date | sed "s/[A-Z]\{3\} [0-9]\{4\}//"`
tmp_ps="/tmp/rlm_ps"
ps > $tmp_ps
pid=`sed -n "s/^ *\([0-9]*\) root.*configd.*$/\1/p" $tmp_ps`
loginfo="$date (none) configd[$pid]:"
rm $tmp_ps

err=0

####################################
#    FILES CHECKING
####################################

if [ -e $tuples ]
then
    rm $tuples
fi

if [ -d $ftpdir ]
then
    : # no-op
else
    mkdir $ftpdir || {
    echo "$loginfo mkdir $ftpdir failed" 1>>$log
    exit 34
}
fi


####################################
#    FRU INFO
####################################
$fw_printenv | sed -n "
/serial#/s/#=/ /p
/part#/s/#=/ /p
/rev#/s/#=/ /p" >>$tuples || {
    echo "$loginfo fail to get env info" 1>>$log
    err=25
}

####################################
#    SOFTWARE VERSION
####################################
echo -n "version " >>$tuples
/usr/local/bin/version.sh -e -r >>$tuples

####################################
#    STATISTIC
####################################
/usr/local/bin/rlm_stats -p > $stats || {
    echo "$loginfo fail to get stats" 1>>$log
    err=34
}


####################################
#    NETWORK INFO
####################################

inet=`sed -n "s/.*eth0 inet \([a-z]*\).*/\1/p" $interfaces` || {
    echo "$loginfo fail to get dhcp info" 1>>$log
    err=25
}
if [ $inet = "dhcp" ]
then
    echo "dhcp 1" >>$tuples
else
    echo "dhcp 0" >>$tuples
fi

ifconfig eth0 | sed -n "s/.*HWaddr \([^ ]*\).*/MAC \1/p" >>$tuples || {
    echo "$loginfo fail to get MAC" 1>>$log
    err=25
}

ifconfig eth0 | sed -n "s/.*inet addr:\([^ ]*\).*/ip \1/p" >>$tuples || {
    echo "$loginfo fail to get ip" 1>>$log
    err=25
}
ifconfig eth0 | sed -n "s/.*Mask:\([^ ]*\).*/netmask \1/p" >>$tuples || {
    echo "$loginfo fail to get netmask" 1>>$log
    err=25
}

route | sed -n "s/.*default *\([^ ]*\).*/gateway \1/p" >>$tuples || {
    echo "$loginfo fail to get gateway" 1>>$log
    err=25
}

####################################
#    SEND TUPLES FILE
####################################


cp $tuples $final_tuples || {
    echo "$loginfo fail to save $final_tuples" 1>>$log
    err=34
}

echo "$loginfo $0 completed, err = $err" 1>>$log


# Once we get to this point just exit with good status for now.
#exit 0
exit $err
