#!/bin/ash
# This script reconfigures the RLM with the info
# from the $tuples.
set -x


####################################
#    FILES CHECKING
####################################

ifup="/sbin/ifup"
ifdown="/sbin/ifdown"

cmd_hostname="/bin/hostname"
do_firewall=0
fw_printenv="/usr/local/bin/fw_printenv"
tuples="/mnt/logs/etc/rlm_config_from_filer"

interfaces="/mnt/logs/etc/interfaces"
tmp_if="/tmp/interfaces"

hostname="/mnt/logs/etc/hostname"

tmp_dns="/tmp/config/etc/resolv.conf"
dns="/mnt/logs/etc/resolv.conf"

firewall="/etc/init.d/firewall"

log="/var/log/messages"
date=`date | sed "s/[A-Z]\{3\} [0-9]\{4\}//"`
tmp_ps="/tmp/rlm_ps"


####################################
#    UP-CONVERT DNS CONFIG FILE     
# This section (and only this) should be run if    
# called during init i.e., with 
# "dns_config" as command line parameter
# Normal invocations without any additional 
# parameters will skip this section.                
####################################

if [ $# -eq 1 -a $1 = "dns_config" ]; then
   if [ -e $dns -a -e $tuples ]; then 
      tmp_dns1="/tmp/resolv.conf"
      grep -q "sp-auto-generated" $dns
      reconfig_needed=$?
      if [ $reconfig_needed -eq 1 ]; then
         dns_domainname=`sed -n "s/^dns.domainname //p" $tuples`
   
         if [ "$dns_domainname" != "" ]; then
            echo "# sp-auto-generated by rlm_conf.sh at init time" > $tmp_dns1
            echo "search $dns_domainname" >> $tmp_dns1
            cat $dns >> $tmp_dns1
            mv -f $tmp_dns1 $dns
         fi
   
      fi
   fi
exit 0
fi
##### End DNS Config converstion #####


##  Generate process id (configd) ##
ps > $tmp_ps
pid=`sed -n "s/^ *\([0-9]*\) root.*configd.*$/\1/p" $tmp_ps`
loginfo="$date (none) configd[$pid]:"
rm $tmp_ps


#
# dgilson: taking out version checking code for now. 
# This needs to be better thought out as to which things can change
# then when this script should run or early exit. Spares and swapping
# in a new RLM needs to be thought about too. 
#
#if [ -e $tuples ]
#then
#
#	tver=`grep tuples_version $tuples | wc -l `
#	newtver=`grep tuples_version $new_tuples | wc -l `
#	if [ $tver != 0 ] 
#	then
#		if [ $newtver != 0 ]
#		then
#			cur_ver=`sed -n "s/^tuples_version //p" $tuples`
#			new_ver=`sed -n "s/^tuples_version //p" $new_tuples`
#			if [ "$cur_ver" = "$new_ver" ]
#			then
#			exit 0
#			fi
#		fi
#	fi
#fi


if [ -e $tuples ]; then
	chmod 0666 $tuples
fi

####################################
#    NETWORK CONFIG
####################################

if [ -e $interfaces ]
then
    cur_inet=`sed -n "s/^[^#].*eth0 inet \([a-z]*\).*/\1/p" $interfaces`
    cur_ip=`sed -n "s/^[^#].*address \([^ ]*\).*/\1/p" $interfaces`
    cur_net=`sed -n "s/^[^#].*netmask \([^ ]*\).*/\1/p" $interfaces`
    cur_gate=`sed -n "s/^[^#].*gateway \([^ ]*\).*/\1/p" $interfaces`
fi

echo "# This file is generated by RLM upon request from Ontap." >$tmp_if
echo "# Do NOT modify this file manually." >>$tmp_if
echo "auto lo" >>$tmp_if
echo "iface lo inet loopback" >>$tmp_if
echo "auto eth0" >>$tmp_if

if [ -e $tuples ]
then
	dhcp=`sed -n "s/^dhcp //p" $tuples`
	if [ $dhcp -eq 0 ]
	then
		ip=`sed -n "s/^ip //p" $tuples`
		net=`sed -n "s/^netmask //p" $tuples`
		gate=`sed -n "s/^gateway //p" $tuples`
	fi
else
	# default to our existing config if we can
	if [ -e $interfaces ]
	then
		if [ "$cur_inet" = "dhcp" ]
		then
			dhcp=1
		else
			dhcp=0
		fi
		ip=$cur_ip
		net=$cur_net
		gate=$cur_gate
	else
		# no directions for network setup, so default to this
		dhcp=0
		ip=192.168.220.2
		net=255.255.255.0
		gate=192.168.220.1
	fi
fi

if [ $dhcp -eq 0 ]
then
	echo "iface eth0 inet static" >>$tmp_if
	echo "   address $ip" >>$tmp_if
	echo "   netmask $net" >>$tmp_if
	echo "   gateway $gate" >>$tmp_if
else
	echo "iface eth0 inet dhcp" >>$tmp_if
fi

# no action if new network info are same as current
#if [ "$cur_inet" = "dhcp" -a $dhcp -eq 0 -o \
#     "$cur_inet" = "static" -a $dhcp -eq 1 -o \
#     "$cur_ip" != "$ip" -o \
#     "$cur_net" != "$net" -o \
#     "$cur_gate" != "$gate" ]
if [ -z "$cur_inet" ]; then
	do_firewall=1
fi

if [ "$cur_inet" = "dhcp" ]; then
	if [ $dhcp -eq 0 ]; then
		do_firewall=1
	fi
else
	if [ "$cur_inet" = "static" ]; then
		if [ $dhcp -eq 1 ]; then
			do_firewall=1
		else
			if [ "$cur_ip" != "$ip" ]; then
				do_firewall=1
			else
				if [ "$cur_net" != "$net" ]; then
					do_firewall=1
				else
					if [ "$cur_gate" != "$gate" ]; then
						do_firewall=1
					fi
				fi
			fi
		fi
	fi
fi


####################################
#    HOSTNAME CONFIG
####################################

$fw_printenv | sed -n "s/serial#=//p" > $hostname || {
    echo "$loginfo failed to save hostname" 1>>$log
    exit 25;
}

$cmd_hostname -F $hostname || {
    echo "$loginfo failed to config hostname" 1>>$log
    exit 25;
}

####################################
#    DNS RESOLUTION
####################################
# dns is optional so do not check the copy
if [ -e $tmp_dns -a -e $tuples ]; then
   dns_domainname=`sed -n "s/^dns.domainname //p" $tuples`
   if [ "$dns_domainname" != "" ]; then
      echo "# sp-auto-generated by rlm_conf.sh invoked by configd" > $dns
      echo "search $dns_domainname" >> $dns
      cat $tmp_dns >> $dns
   else 
      cp $tmp_dns $dns
   fi
fi


####################################
#    IP TABLES
####################################
/usr/local/bin/net_link_up.sh;
if ! [ $? = 1 ]; then {
   exit 28;
}
fi

# Rewrite the file anyway to get the correct format
cp $tmp_if $interfaces || {
    echo "$loginfo can't save $interfaces" 1>>$log
    exit 34
}

if [ $do_firewall -eq 1 ]; then
	$ifdown eth0
	$ifup eth0
	$firewall restart || {
		echo "$loginfo firewall failed" 1>>$log
		exit 34
	}
fi


echo "$loginfo $0 completed" 1>>$log
exit 0
